﻿using System.Windows.Media;
using ff14bot.Helpers;

namespace Charta
{
    public enum LoggerType
    {
        Default,
        Notice,
        Warning,
        Error
    }

    public class cLogger
    {
        private readonly string _messageHead;

        public cLogger()
        {
            _messageHead = "[Charta]: ";
        }

        /// <summary>
        /// Translates the Enum value of LoggerType to the appropriate Color.
        /// </summary>
        /// <param name="logType"></param>
        /// <returns>Color</returns>
        private Color GetColorFromType(LoggerType logType)
        {
            Color retColor;
            switch(logType)
            {
                case LoggerType.Error:
                    retColor =  Colors.OrangeRed;
                    break;
                case LoggerType.Warning:
                    retColor = Colors.DarkOrange;
                    break;
                case LoggerType.Notice:
                    retColor = Colors.Lime;
                    break;
                default:
                    retColor = Colors.Khaki;
                    break;
            }
            return retColor;
        }


        /// <summary>
        /// Logs the message with the defined MessageHead and the default color.
        /// </summary>
        /// <param name="message"></param>
        public void Write(string message)
        {
            message = string.Format("{0} {1}", _messageHead, message);
            Logging.Write(GetColorFromType(LoggerType.Default), message);
        }

        /// <summary>
        /// Logs the message with the defined MessageHead and the specified color.
        /// </summary>
        /// <param name="loggerType"></param>
        /// <param name="message"></param>
        public void Write(LoggerType loggerType, string message)
        {
            message = string.Format("{0} {1}", _messageHead, message);
            Logging.Write(GetColorFromType(loggerType), message);
        }

    }

}
